pub enum Msg<Ctx: Context> {
Subscribe(Box<dyn Subscriber<NetworkEvent<Ctx>>>),
PublishConsensusMsg(SignedConsensusMsg<Ctx>),
PublishLivenessMsg(LivenessMsg<Ctx>),
PublishProposalPart(StreamMessage<Ctx::ProposalPart>),
BroadcastStatus(Status<Ctx>),
OutgoingRequest(PeerId, Request<Ctx>, RpcReplyPort<OutboundRequestId>),
OutgoingResponse(InboundRequestId, Response<Ctx>),
DumpState(RpcReplyPort<Option<NetworkStateDump>>),
UpdatePersistentPeers(PersistentPeersOp, RpcReplyPort<Result<(), PersistentPeerError>>),
UpdateValidatorSet(Ctx::ValidatorSet),
// some variants omitted
}Variants
Subscribe(Box<dyn Subscriber<NetworkEvent<Ctx>>>)
Subscribe this actor to receive gossip events
PublishConsensusMsg(SignedConsensusMsg<Ctx>)
Publish a signed consensus message
PublishLivenessMsg(LivenessMsg<Ctx>)
Publish a liveness message
PublishProposalPart(StreamMessage<Ctx::ProposalPart>)
Publish a proposal part
BroadcastStatus(Status<Ctx>)
Broadcast status to all direct peers
OutgoingRequest(PeerId, Request<Ctx>, RpcReplyPort<OutboundRequestId>)
Send a request to a peer, returning the outbound request ID
OutgoingResponse(InboundRequestId, Response<Ctx>)
Send a response for a request to a peer
DumpState(RpcReplyPort<Option<NetworkStateDump>>)
Request to dump the current network state
UpdatePersistentPeers(PersistentPeersOp, RpcReplyPort<Result<(), PersistentPeerError>>)
Add or remove a persistent peer at runtime
UpdateValidatorSet(Ctx::ValidatorSet)
Update the validator set for the current height