pub struct NetworkIdentity {
pub moniker: String,
pub keypair: Keypair,
pub consensus_address: Option<String>,
}Expand description
Node identity bundling all node-specific information.
The consensus address is derived from the keypair in the current implementation where libp2p and consensus use the same key. In the future, when using separate keys (e.g., cc-signer for consensus), the address will be provided separately.
If consensus_address is None, the node will not advertise a validator address and cannot become a validator.
Fields
moniker: Stringkeypair: Keypairconsensus_address: Option<String>Implementations
Sourceimpl NetworkIdentity
impl NetworkIdentity
Sourcepub fn new(
moniker: String,
keypair: Keypair,
consensus_address: Option<String>,
) -> NetworkIdentity
pub fn new( moniker: String, keypair: Keypair, consensus_address: Option<String>, ) -> NetworkIdentity
Create a new NodeIdentity.
Arguments
moniker- Human-readable node identifierkeypair- libp2p keypair for network authenticationconsensus_address- Optional consensus address (Some = potential validator, None = full node)
In the current implementation where libp2p and consensus share the same key, the address is typically derived from the keypair before calling this method. In the future with cc-signer, the consensus address will be separate.