pub enum Msg<Ctx: Context> {
Tick,
NetworkEvent(NetworkEvent<Ctx>),
Decided(Ctx::Height),
StartedHeight(Ctx::Height, HeightStartType),
GotDecidedValues(InboundRequestId, RangeInclusive<Ctx::Height>, Vec<RawDecidedValue<Ctx>>),
TimeoutElapsed(TimeoutElapsed<Timeout>),
InvalidValue(PeerId, Ctx::Height),
ValueProcessingError(PeerId, Ctx::Height),
}Variants
Tick
Internal tick
NetworkEvent(NetworkEvent<Ctx>)
Receive an even from gossip layer
Decided(Ctx::Height)
Consensus has decided on a value at the given height
StartedHeight(Ctx::Height, HeightStartType)
Consensus has (re)started a new height.
The second argument indicates whether this is a restart or not.
GotDecidedValues(InboundRequestId, RangeInclusive<Ctx::Height>, Vec<RawDecidedValue<Ctx>>)
Host has a response for the blocks request
TimeoutElapsed(TimeoutElapsed<Timeout>)
A timeout has elapsed
InvalidValue(PeerId, Ctx::Height)
We received an invalid value (either certificate or value) from a peer
ValueProcessingError(PeerId, Ctx::Height)
An error occurred while processing a value