pub trait SyncCodec<Ctx>{ }Expand description
Codec for sync protocol messages
This trait is automatically implemented for any type that implements:
pub trait SyncCodec<Ctx>{ }Codec for sync protocol messages
This trait is automatically implemented for any type that implements: