SyncMsg

Type Alias SyncMsg 

pub type SyncMsg<Ctx> = Msg<Ctx>;

Aliased Type

pub enum SyncMsg<Ctx> {
    Tick,
    NetworkEvent(NetworkEvent<Ctx>),
    Decided(<Ctx as Context>::Height),
    StartedHeight(<Ctx as Context>::Height, HeightStartType),
    GotDecidedValues(InboundRequestId, RangeInclusive<<Ctx as Context>::Height>, Vec<RawDecidedValue<Ctx>>),
    TimeoutElapsed(TimeoutElapsed<Timeout>),
    InvalidValue(PeerId, <Ctx as Context>::Height),
    ValueProcessingError(PeerId, <Ctx as Context>::Height),
}

Variants



Tick

Internal tick



NetworkEvent(NetworkEvent<Ctx>)

Receive an even from gossip layer



Decided(<Ctx as Context>::Height)

Consensus has decided on a value at the given height



StartedHeight(<Ctx as Context>::Height, HeightStartType)

Consensus has (re)started a new height.

The second argument indicates whether this is a restart or not.



GotDecidedValues(InboundRequestId, RangeInclusive<<Ctx as Context>::Height>, Vec<RawDecidedValue<Ctx>>)

Host has a response for the blocks request



TimeoutElapsed(TimeoutElapsed<Timeout>)

A timeout has elapsed



InvalidValue(PeerId, <Ctx as Context>::Height)

We received an invalid value (either certificate or value) from a peer



ValueProcessingError(PeerId, <Ctx as Context>::Height)

An error occurred while processing a value