pub struct StreamMessage<T> {
pub stream_id: StreamId,
pub sequence: Sequence,
pub content: StreamContent<T>,
}Fields
stream_id: StreamIdReceivers identify streams by (sender, stream_id). This means each node can allocate stream_ids independently and that many streams can be sent on a single network topic.
sequence: SequenceIdentifies the sequence of each message in the stream starting from 0.
content: StreamContent<T>The content of this stream message
Implementations