TimerScheduler

Struct TimerScheduler 

pub struct TimerScheduler<Key>
where Key: Clone + Eq + Hash + Send + 'static,
{ /* private fields */ }

Implementations

Source

impl<Key> TimerScheduler<Key>
where Key: Clone + Eq + Hash + Send + 'static,

pub fn new(subscriber: OutputPortSubscriber<TimeoutElapsed<Key>>) -> Self

pub fn start_timer(&mut self, key: Key, timeout: Duration)
where Key: Clone + Send + 'static,

Start a timer that will send msg once to the actor after the given timeout.

Each timer has a key and if a new timer with same key is started the previous is cancelled.

Warning

It is NOT guaranteed that a message from the previous timer is not received, as it could already be enqueued in the mailbox when the new timer was started.

When the actor receives a timeout message for timer from the scheduler, it should check if the timer is still active by calling TimerScheduler::intercept_timer_msg and ignore the message otherwise.

pub fn is_timer_active(&self, key: &Key) -> bool

Check if a timer with a given key is active, ie. it hasn’t been canceled nor has it elapsed yet.

pub fn cancel(&mut self, key: &Key)

Cancel a timer with a given key.

If canceling a timer that was already canceled, or key never was used to start a timer this operation will do nothing.

Warning

It is NOT guaranteed that a message from a canceled timer, including its previous incarnation for the same key, will not be received by the actor, as the message might already be enqueued in the mailbox when cancel is called.

When the actor receives a timeout message for timer from the scheduler, it should check if the timer is still active by calling TimerScheduler::intercept_timer_msg and ignore the message otherwise.

pub fn cancel_all(&mut self)

Cancel all timers.

pub fn intercept_timer_msg( &mut self, timer_msg: TimeoutElapsed<Key>, ) -> Option<Key>
where Key: Debug,

Intercepts a timer message and checks the state of the timer associated with the provided timer_msg:

  1. If the timer message was from canceled timer that was already enqueued in mailbox, returns None.
  2. If the timer message was from an old timer that was enqueued in mailbox before being canceled, returns None.
  3. Otherwise it is a valid timer message, returns the associated Key wrapped in Some.