pub enum ConsensusError<Ctx>where
Ctx: Context,{
UnexpectedResume(Resume<Ctx>, &'static str),
ProposerNotFound(<Ctx as Context>::Height, Round),
DecisionNotFound(<Ctx as Context>::Height, Round),
DriverProposalNotFound(<Ctx as Context>::Height, Round),
FullProposalNotFound(<Ctx as Context>::Height, Round),
DriverProcess(Error<Ctx>),
ValidatorSetNotFound(<Ctx as Context>::Height),
InvalidCommitCertificate(CommitCertificate<Ctx>, CertificateError<Ctx>),
MissingPolkaCertificate(<Ctx as Context>::Height, Round, <<Ctx as Context>::Value as Value>::Id, &'static str),
WalCorrupted(Arc<Error>),
}Expand description
The types of error that can be emitted by the consensus process.
Variants
UnexpectedResume(Resume<Ctx>, &'static str)
The consensus process was resumed with a value which does not match the expected type of resume value.
ProposerNotFound(<Ctx as Context>::Height, Round)
The proposer was not found at the given height and round.
DecisionNotFound(<Ctx as Context>::Height, Round)
State machine has no decision in commit step.
DriverProposalNotFound(<Ctx as Context>::Height, Round)
Driver proposal not found in commit step.
FullProposalNotFound(<Ctx as Context>::Height, Round)
Full proposal not found in commit step.
DriverProcess(Error<Ctx>)
The driver failed to process an input.
ValidatorSetNotFound(<Ctx as Context>::Height)
The validator set was not found at the given height.
InvalidCommitCertificate(CommitCertificate<Ctx>, CertificateError<Ctx>)
The certificate is invalid.
MissingPolkaCertificate(<Ctx as Context>::Height, Round, <<Ctx as Context>::Value as Value>::Id, &'static str)
Missing polka certificate.
WalCorrupted(Arc<Error>)
The write-ahead log is corrupted.